@@ -1,3 +1,3 @@
-from cromp.src.train import CROMPTrain
+from cromp.src.train_v2 import CROMPTrain
 from cromp.src.predict import CROMPPredict
 
